@@ -42,7 +42,7 @@ class WebDriver(object):
         desired_capabilities=None, browser_profile=None):
         """
         Create a new driver that will issue commands using the wire protocol.
-        
+
         :Args:
          - command_executor - Either a command.CommandExecutor object or a string that specifies the URL of a remote server to send commands to.
          - desired_capabilities - Dictionary holding predefined values for starting a browser
@@ -62,7 +62,7 @@ class WebDriver(object):
     @property
     def name(self):
         """Returns the name of the underlying browser for this instance.
-        
+
         :Usage:
          - driver.name
         """
@@ -88,7 +88,7 @@ class WebDriver(object):
     def start_session(self, desired_capabilities, browser_profile=None):
         """
         Creates a new session with the desired capabilities.
-        
+
         :Args:
          - browser_name - The name of the browser to request.
          - version - Which browser version to request.
@@ -134,11 +134,11 @@ class WebDriver(object):
     def execute(self, driver_command, params=None):
         """
         Sends a command to be executed by a command.CommandExecutor.
-        
+
         :Args:
          - driver_command: The name of the command to execute as a string.
          - params: A dictionary of named parameters to send with the command.
-        
+
         :Returns:
           The command's JSON response loaded into a dictionary object.
         """
@@ -167,7 +167,7 @@ class WebDriver(object):
     @property
     def title(self):
         """Returns the title of the current page.
-        
+
         :Usage:
             driver.title
         """
@@ -176,10 +176,10 @@ class WebDriver(object):
 
     def find_element_by_id(self, id_):
         """Finds an element by id.
-        
+
         :Args:
          - id\_ - The id of the element to be found.
-        
+
         :Usage:
             driver.find_element_by_id('foo')
         """
@@ -188,7 +188,7 @@ class WebDriver(object):
     def find_elements_by_id(self, id_):
         """
         Finds multiple elements by id.
-        
+
         :Args:
          - id\_ - The id of the elements to be found.
 
@@ -200,7 +200,7 @@ class WebDriver(object):
     def find_element_by_xpath(self, xpath):
         """
         Finds an element by xpath.
-        
+
         :Args:
          - xpath - The xpath locator of the element to find.
 
@@ -212,10 +212,10 @@ class WebDriver(object):
     def find_elements_by_xpath(self, xpath):
         """
         Finds multiple elements by xpath.
-        
+
         :Args:
          - xpath - The xpath locator of the elements to be found.
-        
+
         :Usage:
             driver.find_elements_by_xpath("//div[contains(@class, 'foo')]")
         """
@@ -224,10 +224,10 @@ class WebDriver(object):
     def find_element_by_link_text(self, link_text):
         """
         Finds an element by link text.
-        
+
         :Args:
          - link_text: The text of the element to be found.
-        
+
         :Usage:
             driver.find_element_by_link_text('Sign In')
         """
@@ -236,10 +236,10 @@ class WebDriver(object):
     def find_elements_by_link_text(self, text):
         """
         Finds elements by link text.
-        
+
         :Args:
          - link_text: The text of the elements to be found.
-        
+
         :Usage:
             driver.find_elements_by_link_text('Sign In')
         """
@@ -248,10 +248,10 @@ class WebDriver(object):
     def find_element_by_partial_link_text(self, link_text):
         """
         Finds an element by a partial match of its link text.
-        
+
         :Args:
          - link_text: The text of the element to partially match on.
-        
+
         :Usage:
             driver.find_element_by_partial_link_text('Sign')
         """
@@ -260,10 +260,10 @@ class WebDriver(object):
     def find_elements_by_partial_link_text(self, link_text):
         """
         Finds elements by a partial match of their link text.
-        
+
         :Args:
          - link_text: The text of the element to partial match on.
-        
+
         :Usage:
             driver.find_element_by_partial_link_text('Sign')
         """
@@ -272,10 +272,10 @@ class WebDriver(object):
     def find_element_by_name(self, name):
         """
         Finds an element by name.
-        
+
         :Args:
          - name: The name of the element to find.
-        
+
         :Usage:
             driver.find_element_by_name('foo')
         """
@@ -284,10 +284,10 @@ class WebDriver(object):
     def find_elements_by_name(self, name):
         """
         Finds elements by name.
-        
+
         :Args:
          - name: The name of the elements to find.
-        
+
         :Usage:
             driver.find_elements_by_name('foo')
         """
@@ -296,10 +296,10 @@ class WebDriver(object):
     def find_element_by_tag_name(self, name):
         """
         Finds an element by tag name.
-        
+
         :Args:
          - name: The tag name of the element to find.
-        
+
         :Usage:
             driver.find_element_by_tag_name('foo')
         """
@@ -308,10 +308,10 @@ class WebDriver(object):
     def find_elements_by_tag_name(self, name):
         """
         Finds elements by tag name.
-        
+
         :Args:
          - name: The tag name the use when finding elements.
-        
+
         :Usage:
             driver.find_elements_by_tag_name('foo')
         """
@@ -320,10 +320,10 @@ class WebDriver(object):
     def find_element_by_class_name(self, name):
         """
         Finds an element by class name.
-        
+
         :Args:
          - name: The class name of the element to find.
-        
+
         :Usage:
             driver.find_element_by_class_name('foo')
         """
@@ -332,10 +332,10 @@ class WebDriver(object):
     def find_elements_by_class_name(self, name):
         """
         Finds elements by class name.
-        
+
         :Args:
          - name: The class name of the elements to find.
-        
+
         :Usage:
             driver.find_elements_by_class_name('foo')
         """
@@ -344,10 +344,10 @@ class WebDriver(object):
     def find_element_by_css_selector(self, css_selector):
         """
         Finds an element by css selector.
-        
+
         :Args:
          - css_selector: The css selector to use when finding elements.
-        
+
         :Usage:
             driver.find_element_by_css_selector('#foo')
         """
@@ -356,10 +356,10 @@ class WebDriver(object):
     def find_elements_by_css_selector(self, css_selector):
         """
         Finds elements by css selector.
-        
+
         :Args:
          - css_selector: The css selector to use when finding elements.
-        
+
         :Usage:
             driver.find_element_by_css_selector('#foo')
         """
@@ -368,11 +368,11 @@ class WebDriver(object):
     def execute_script(self, script, *args):
         """
         Synchronously Executes JavaScript in the current window/frame.
-        
+
         :Args:
          - script: The JavaScript to execute.
          - \*args: Any applicable arguments for your JavaScript.
-        
+
         :Usage:
             driver.execute_script('document.title')
         """
@@ -387,11 +387,11 @@ class WebDriver(object):
     def execute_async_script(self, script, *args):
         """
         Asynchronously Executes JavaScript in the current window/frame.
-        
+
         :Args:
          - script: The JavaScript to execute.
          - \*args: Any applicable arguments for your JavaScript.
-        
+
         :Usage:
             driver.execute_async_script('document.title')
         """
@@ -407,7 +407,7 @@ class WebDriver(object):
     def current_url(self):
         """
         Gets the URL of the current page.
-        
+
         :Usage:
             driver.current_url
         """
@@ -417,7 +417,7 @@ class WebDriver(object):
     def page_source(self):
         """
         Gets the source of the current page.
-        
+
         :Usage:
             driver.page_source
         """
@@ -426,7 +426,7 @@ class WebDriver(object):
     def close(self):
         """
         Closes the current window.
-        
+
         :Usage:
             driver.close()
         """
@@ -435,7 +435,7 @@ class WebDriver(object):
     def quit(self):
         """
         Quits the driver and closes every associated window.
-        
+
         :Usage:
             driver.quit()
         """
@@ -448,7 +448,7 @@ class WebDriver(object):
     def current_window_handle(self):
         """
         Returns the handle of the current window.
-        
+
         :Usage:
             driver.current_window_handle
         """
@@ -458,7 +458,7 @@ class WebDriver(object):
     def window_handles(self):
         """
         Returns the handles of all windows within the current session.
-        
+
         :Usage:
             driver.window_handles
         """
@@ -468,7 +468,7 @@ class WebDriver(object):
     def switch_to_active_element(self):
         """
         Returns the element with focus, or BODY if nothing has focus.
-        
+
         :Usage:
             driver.switch_to_active_element()
         """
@@ -477,10 +477,10 @@ class WebDriver(object):
     def switch_to_window(self, window_name):
         """
         Switches focus to the specified window.
-        
+
         :Args:
          - window_name: The name of the window to switch to.
-        
+
         :Usage:
             driver.switch_to_window('main')
         """
@@ -489,7 +489,7 @@ class WebDriver(object):
     def switch_to_frame(self, frame_reference):
         """
         Switches focus to the specified frame, by index, name, or webelement.
-        
+
         :Args:
          - frame_reference: The name of the window to switch to, an integer representing the index,
                             or a webelement that is an (i)frame to switch to.
@@ -504,7 +504,7 @@ class WebDriver(object):
     def switch_to_default_content(self):
         """
         Switch focus to the default frame.
-        
+
         :Usage:
             driver.switch_to_default_content()
         """
@@ -513,7 +513,7 @@ class WebDriver(object):
     def switch_to_alert(self):
         """
         Switches focus to an alert on the page.
-        
+
         :Usage:
             driver.switch_to_alert()
         """
@@ -523,7 +523,7 @@ class WebDriver(object):
     def back(self):
         """
         Goes one step backward in the browser history.
-        
+
         :Usage:
             driver.back()
         """
@@ -532,7 +532,7 @@ class WebDriver(object):
     def forward(self):
         """
         Goes one step forward in the browser history.
-        
+
         :Usage:
             driver.forward()
         """
@@ -541,7 +541,7 @@ class WebDriver(object):
     def refresh(self):
         """
         Refreshes the current page.
-        
+
         :Usage:
             driver.refresh()
         """
@@ -551,7 +551,7 @@ class WebDriver(object):
     def get_cookies(self):
         """
         Returns a set of dictionaries, corresponding to cookies visible in the current session.
-        
+
         :Usage:
             driver.get_cookies()
         """
@@ -560,7 +560,7 @@ class WebDriver(object):
     def get_cookie(self, name):
         """
         Get a single cookie by name. Returns the cookie if found, None if not.
-        
+
         :Usage:
             driver.get_cookie('my_cookie')
         """
@@ -573,7 +573,7 @@ class WebDriver(object):
     def delete_cookie(self, name):
         """
         Deletes a single cookie with the given name.
-        
+
         :Usage:
             driver.delete_cookie('my_cookie')
         """
@@ -582,7 +582,7 @@ class WebDriver(object):
     def delete_all_cookies(self):
         """
         Delete all cookies in the scope of the session.
-        
+
         :Usage:
             driver.delete_all_cookies()
         """
@@ -591,12 +591,12 @@ class WebDriver(object):
     def add_cookie(self, cookie_dict):
         """
         Adds a cookie to your current session.
-        
+
         :Args:
          - cookie_dict: A dictionary object, with required keys - "name" and "value";
             optional keys - "path", "domain", "secure", "expiry"
 
-        Usage: 
+        Usage:
             driver.add_cookie({'name' : 'foo', 'value' : 'bar'})
             driver.add_cookie({'name' : 'foo', 'value' : 'bar', 'path' : '/'})
             driver.add_cookie({'name' : 'foo', 'value' : 'bar', 'path' : '/', 'secure':True})
@@ -608,8 +608,10 @@ class WebDriver(object):
     def implicitly_wait(self, time_to_wait):
         """
         Sets a sticky timeout to implicitly wait for an element to be found,
-           or a command to complete. This method only needs to be called one time per session.
-        
+           or a command to complete. This method only needs to be called one
+           time per session. To set the timeout for calls to
+           execute_async_script, see set_script_timeout.
+
         :Args:
          - time_to_wait: Amount of time to wait (in seconds)
 
@@ -620,12 +622,12 @@ class WebDriver(object):
 
     def set_script_timeout(self, time_to_wait):
         """
-        Set the amount of time that the script should wait before throwing an
-           error.
-        
+        Set the amount of time that the script should wait during an
+           execute_async_script call before throwing an error.
+
         :Args:
          - time_to_wait: The amount of time to wait
-        
+
         :Usage:
             driver.set_script_timeout(30)
         """
@@ -635,7 +637,7 @@ class WebDriver(object):
     def find_element(self, by=By.ID, value=None):
         """
         'Private' method used by the find_element_by_* methods.
-        
+
         :Usage:
             Use the corresponding find_element_by_* instead of this.
         """
@@ -645,7 +647,7 @@ class WebDriver(object):
     def find_elements(self, by=By.ID, value=None):
         """
         'Private' method used by the find_elements_by_* methods.
-        
+
         :Usage:
             Use the corresponding find_elements_by_* instead of this.
         """
@@ -662,10 +664,10 @@ class WebDriver(object):
         """
         Gets the screenshot of the current window. Returns False if there is
            any IOError, else returns True. Use full paths in your filename.
-        
+
         :Args:
          - filename: The full path you wish to save your screenshot to.
-        
+
         :Usage:
             driver.get_screenshot_as_file('/Screenshots/foo.png')
         """
@@ -682,7 +684,7 @@ class WebDriver(object):
         """
         Gets the screenshot of the current window as a base64 encoded string
            which is useful in embedded images in HTML.
-        
+
         :Usage:
             driver.get_screenshot_as_base64()
         """
@@ -691,11 +693,11 @@ class WebDriver(object):
     def set_window_size(self, width, height, windowHandle='current'):
         """
         Sets the width and height of the current window. (window.resizeTo)
-        
+
         :Args:
          - width: the width in pixels to set the window to
          - height: the height in pixels to set the window to
-        
+
         :Usage:
             driver.set_window_size(800,600)
         """
@@ -705,7 +707,7 @@ class WebDriver(object):
     def get_window_size(self, windowHandle='current'):
         """
         Gets the width and height of the current window.
-        
+
         :Usage:
             driver.get_window_size()
         """
@@ -715,11 +717,11 @@ class WebDriver(object):
     def set_window_position(self, x, y, windowHandle='current'):
         """
         Sets the x,y position of the current window. (window.moveTo)
-        
+
         :Args:
          - x: the x-coordinate in pixels to set the window position
          - y: the y-coordinate in pixels to set the window position
-        
+
         :Usage:
             driver.set_window_position(0,0)
         """
@@ -729,7 +731,7 @@ class WebDriver(object):
     def get_window_position(self, windowHandle='current'):
         """
         Gets the x,y position of the current window.
-        
+
         :Usage:
             driver.get_window_position()
         """
@@ -762,5 +764,3 @@ class WebDriver(object):
             self.execute(Command.SET_SCREEN_ORIENTATION, {'orientation': value})['value']
         else:
             raise WebDriverException("You can only set the orientation to 'LANDSCAPE' and 'PORTRAIT'")
-
-
